package com.qs.mp.web.controller.api.channel;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.qs.mp.channel.domain.Channel;
import com.qs.mp.channel.domain.ChannelTicketTransfer;
import com.qs.mp.channel.domain.param.ChannelMyTicketQueryParam;
import com.qs.mp.channel.domain.param.ChannelTicketTransferParam;
import com.qs.mp.channel.domain.vo.ChannelMyTicketVO;
import com.qs.mp.channel.service.IChannelOrderDetailService;
import com.qs.mp.channel.service.IChannelService;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.enums.TicketPkgSaleStatusEnum;
import com.qs.mp.common.utils.StringUtils;
import com.qs.mp.utils.SecurityUtils;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 我的盲票相关接口
 * @author Cup
 * @date 2022/4/21
 */
@RestController
@RequestMapping("/api/v1/mp/channel/my/ticket")
@Api(tags = "我的盲票相关接口")
public class ChannelMyTicketController extends BaseApiController {

    @Autowired
    private IChannelOrderDetailService channelOrderDetailService;

    @Autowired
    private IChannelService channelService;

    @PostMapping("list")
    @ApiOperation("我的盲票列表")
    @ApiResponses(
            @ApiResponse(code = 200, message = "成功", response = ChannelMyTicketVO.class)
    )
    public AjaxResult list(@RequestBody ChannelMyTicketQueryParam channelMyTicketQueryParam) {
        Long channelId = SecurityUtils.getLoginUser().getChannelId();
        if (channelId == null) {
            return AjaxResult.error("非法调用");
        }

        startPage();
        // 获取我的盲票列表
        List<ChannelMyTicketVO> list =  channelOrderDetailService.listMyTicket(channelId, channelMyTicketQueryParam);

        return AjaxResult.success(list);
    }

    @PostMapping("/channel/mobile")
    @ApiOperation("根据手机号获取经销商信息")
    @ApiResponses(
            @ApiResponse(code = 200, message = "成功", response = Channel.class)
    )
    public AjaxResult channelInfoByMobile(@RequestBody String mobile) {
        Long channelId = SecurityUtils.getLoginUser().getChannelId();
        if (channelId == null) {
            return AjaxResult.error("非法调用");
        }
        if (StringUtils.isBlank(mobile)) {
            return AjaxResult.success();
        }
        Channel channel = channelService.getOne(new LambdaQueryWrapper<Channel>().eq(Channel::getMobile, mobile));

        return AjaxResult.success(channel);
    }





}
